#
# spec file for package ghc-indexed-traversable
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name indexed-traversable
%global pkgver %{pkg_name}-%{version}
Name:           ghc-%{pkg_name}
Version:        0.1.3
Release:        1.1
Summary:        FunctorWithIndex, FoldableWithIndex, TraversableWithIndex
License:        BSD-2-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-array-devel
BuildRequires:  ghc-array-prof
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-foldable1-classes-compat-devel
BuildRequires:  ghc-foldable1-classes-compat-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-transformers-prof
ExcludeArch:    %{ix86}

%description
This package provides three useful generalizations:

' class Functor f => FunctorWithIndex i f | f -> i where imap :: (i -> a -> b)
-> f a -> f b '

' class Foldable f => FoldableWithIndex i f | f -> i where ifoldMap :: Monoid m
=> (i -> a -> m) -> f a -> m '

' class (FunctorWithIndex i t, FoldableWithIndex i t, Traversable t) =>
TraversableWithIndex i t | t -> i where itraverse :: Applicative f => (i -> a
-> f b) -> t a -> f (t b) '

This package contains instances for types in GHC boot libraries. For some
additional instances see
[indexed-traversable-instances](https://hackage.haskell.org/package/indexed-traversable-instances).

The [keys](https://hackage.haskell.org/package/keys) package provides similar
functionality, but uses (associated) 'TypeFamilies' instead of
'FunctionalDependencies'.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development
files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc Changelog.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Wed Oct  4 2023 Peter Simons <psimons@suse.com>
- Update indexed-traversable to version 0.1.3.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/indexed-traversable-0.1.3/src/Changelog.md
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Sun Mar 12 2023 Peter Simons <psimons@suse.com>
- Update indexed-traversable to version 0.1.2.1.
  [#] 0.1.2.1 [2022-12-28]
  - TraversableWithIndex [] doesn't use `zip [0..]` idiom anymore.
    https://gitlab.haskell.org/ghc/ghc/-/issues/22673
* Wed Aug 10 2022 Peter Simons <psimons@suse.com>
- Update indexed-traversable to version 0.1.2 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Nov 16 2021 psimons@suse.com
- Update indexed-traversable to version 0.1.2 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Nov  1 2021 psimons@suse.com
- Update indexed-traversable to version 0.1.2.
  [#] 0.1.2 [2021-10-30]
  - Changed `(<$>)` + `(<*>)` to `liftA2` to potentially avoid extra `fmap`.
  - Add `(#..)`, coercive composition after a 2-parameter function.
  - Switched references to lens 'Of'- functions to base functions.
  Thanks to wygulmage for contributions.
* Wed Jul 28 2021 psimons@suse.com
- Update indexed-traversable to version 0.1.1 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Sun Dec 27 2020 psimons@suse.com
- Update indexed-traversable to version 0.1.1.
  [#] 0.1.1 [2020-12-27]
  - Mark all modules as `Safe`.
    See https://gitlab.haskell.org/ghc/ghc/-/issues/19127
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Wed Dec 16 2020 psimons@suse.com
- Add indexed-traversable at version 0.1.
